| d2.data.frame | R Documentation |
Produces text input for D2 to make a diagram of a given data frame, usually rendered with SVG.
## S3 method for class 'data.frame'
d2(x, name = NA_character_, nest_level = Inf, ...)
x |
a data.frame. |
name |
a character scalar, giving the name of the record, if any. The
name must be non-empty, since it is also used to name the single table in
the plot. Defaults to |
nest_level |
an integer, giving the amount of nesting allowed when giving the class of a list column. Since lists can hold anything in R, this allows showing common element classes and lengths. |
... |
further arguments passed to or from other methods. |
The rows in the plotted data frame include information about the attribute classes.
A scalar character, containing text input for Graphviz.
The generic d2.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.