d2.relation: Generate D2 input text to plot relations

View source: R/plot.r

d2.relationR Documentation

Generate D2 input text to plot relations

Description

Produces text input for D2 to make a diagram of a given relation, usually rendered with SVG.

Usage

## S3 method for class 'relation'
d2(x, name = NA_character_, nest_level = Inf, ...)

Arguments

x

a relation.

name

a character scalar, giving the name of the schema, if any.

nest_level

an integer, giving the amount of nesting allowed when giving the class of a list column. Since lists can hold anything in R, this allows showing common element classes and lengths.

...

further arguments passed to or from other methods.

Details

Each relation is presented as a set of rows, one for each attribute in the relation. These rows include information about the attribute classes.

Value

A scalar character, containing text input for D2.

See Also

The generic d2.


autodb documentation built on Aug. 4, 2026, 1:08 a.m.