Skip to contents

Produces text input for Graphviz to make an HTML diagram of a given data frame.

Usage

# S3 method for class 'data.frame'
gv(x, name = NA_character_, nest_level = Inf, ...)

Arguments

x

a data.frame.

name

a character scalar, giving the name of the record, if any. The name must be non-empty, since it is also used to name the single table in the plot. Defaults to NA: if left missing, it is set to "data".

nest_level

an integer, giving the amount of nesting allowed when giving the class of a list column. Since lists can hold anything in R, this allows showing common element classes and lengths.

...

further arguments passed to or from other methods.

Value

A scalar character, containing text input for Graphviz.

Details

The rows in the plotted data frame include information about the attribute classes.

See also

The generic gv.