gv.relation: Generate Graphviz input text to plot relations

View source: R/plot.r

gv.relationR Documentation

Generate Graphviz input text to plot relations

Description

Produces text input for Graphviz to make an HTML diagram of a given relation.

Usage

## S3 method for class 'relation'
gv(x, name = NA_character_, nest_level = Inf, ...)

Arguments

x

a relation.

name

a character scalar, giving the name of the schema, if any.

nest_level

an integer, giving the amount of nesting allowed when giving the class of a list column. Since lists can hold anything in R, this allows showing common element classes and lengths.

...

further arguments passed to or from other methods.

Details

Each relation is presented as a set of rows, one for each attribute in the relation. These rows include information about the attribute classes.

Value

A scalar character, containing text input for Graphviz.

See Also

The generic gv.


autodb documentation built on Aug. 4, 2026, 1:08 a.m.