| autokey | R Documentation |
This is a wrapper function for applying discover_keys,
relation_schema, create, and
insert. This takes a data frame and adds its keys, resulting in
a single relation. If only the keys are required, this can be much quicker
than running autodb.
autokey(
df,
keep_rownames = FALSE,
digits = getOption("digits"),
progress = FALSE,
progress_file = "",
...
)
df |
a data.frame, containing the data to be normalised. |
keep_rownames |
a logical or a string, indicating whether to include the row names as a column. If a string is given, it is used as the name for the column, otherwise the column is named "row". Like with the other column names, the function returns an error if this results in duplicate column names. Set to FALSE by default. |
digits |
a positive integer, indicating how many significant digits are
to be used for numeric and complex variables. This is used for both
pre-formatting in |
progress |
a logical, for whether to display progress to the user during
dependency search in |
progress_file |
a scalar character or a connection. If |
... |
further arguments passed on to |
A relation of length 1, containing the data in
df and its keys.
# simple example
autokey(ChickWeight)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.