gv.database: Generate Graphviz input text to plot databases

View source: R/plot.r

gv.databaseR Documentation

Generate Graphviz input text to plot databases

Description

Produces text input for Graphviz to make an HTML diagram of a given database.

Usage

## S3 method for class 'database'
gv(x, name = NA_character_, nest_level = Inf, ...)

Arguments

x

a database, as returned by autoref or autodb.

name

a scalar character, giving the name of the database, if any. This name is used for the resulting graph, to allow for easier combining of graphs into a single diagram if required.

nest_level

an integer, giving the amount of nesting allowed when giving the class of a list column. Since lists can hold anything in R, this allows showing common element classes and lengths.

...

further arguments passed to or from other methods.

Details

Each relation in the database is presented as a set of rows, one for each attribute in the relation. These rows include information about the attribute classes.

Value

A scalar character, containing text input for Graphviz.

See Also

The generic gv.


autodb documentation built on Aug. 4, 2026, 1:08 a.m.