Learn R Programming

autodb (version 3.3.1)

gv.database: Generate Graphviz input text to plot databases

Description

Produces text input for Graphviz to make an HTML diagram of a given database.

Usage

# S3 method for database
gv(x, name = NA_character_, nest_level = Inf, ...)

Value

A scalar character, containing text input for Graphviz.

Arguments

x

a database, as returned by autoref or autodb.

name

a scalar character, giving the name of the database, if any. This name is used for the resulting graph, to allow for easier combining of graphs into a single diagram if required.

nest_level

an integer, giving the amount of nesting allowed when giving the class of a list column. Since lists can hold anything in R, this allows showing common element classes and lengths.

...

further arguments passed to or from other methods.

Details

Each relation in the database is presented as a set of rows, one for each attribute in the relation. These rows include information about the attribute classes.

See Also

The generic gv.