Produces text input for Graphviz to make an HTML diagram of a given database.
# S3 method for database
gv(x, name = NA_character_, nest_level = Inf, ...)A scalar character, containing text input for Graphviz.
a database, as returned by autoref or
autodb.
a scalar character, giving the name of the database, if any. This name is used for the resulting graph, to allow for easier combining of graphs into a single diagram if required.
an integer, giving the amount of nesting allowed when giving the class of a list column. Since lists can hold anything in R, this allows showing common element classes and lengths.
further arguments passed to or from other methods.
Each relation in the database is presented as a set of rows, one for each attribute in the relation. These rows include information about the attribute classes.
The generic gv.